@@ -2,7 +2,7 @@
 DSLIBRARY - run your data science code anywhere.
 
 """
-__version__ = "0.0.11"
+__version__ = "0.0.12"
 
 # environment variables
 from .front import ENV_DSLIBRARY_TARGET, ENV_DSLIBRARY_SPEC, ENV_DSLIBRARY_TOKEN
@@ -112,8 +112,12 @@ log_dict = _DEFAULT.log_dict
 log_text = _DEFAULT.log_text
 get_sql_connection = _DEFAULT.get_sql_connection
 open_run_data = _DEFAULT.open_run_data
+read_run_data = _DEFAULT.read_run_data
+write_run_data = _DEFAULT.write_run_data
 set_evaluation_result = _DEFAULT.set_evaluation_result
 open_model_binary = _DEFAULT.open_model_binary
+load_pickled_model = _DEFAULT.load_pickled_model
+save_pickled_model = _DEFAULT.save_pickled_model
 read_resource = _DEFAULT.read_resource
 start_run = _DEFAULT.start_run
 end_run = _DEFAULT.end_run
@@ -121,8 +125,6 @@ active_run = _DEFAULT.active_run
 get_metadata = _DEFAULT.get_metadata
 get_uri = _DEFAULT.get_uri
 get_last_metric = _DEFAULT.get_last_metric
-load_pickled_model = _DEFAULT.load_pickled_model
-save_pickled_model = _DEFAULT.save_pickled_model
 get_filesystem_connection = _DEFAULT.get_filesystem_connection
-install_pacakges = _DEFAULT.install_packages
+install_packages = _DEFAULT.install_packages
 # TODO there may be more methods to add here
