@@ -71,6 +71,16 @@ class DSLibrary(object):
         if self._mlflow_opts and not mlflow:
             raise DSLibraryException("MLFlow was selected for output but the mlflow package is not installed")
         self._mlflow_run = None
+        self._setup_code_paths()
+
+    def _setup_code_paths(self):
+        """
+        A list of folders containing required modules can be specified.
+        """
+        # set up code paths - locations of required source files
+        for path in self._spec.get("code_paths") or []:
+            if path not in sys.path:
+                sys.path.append(path)
 
     def _xlt_resource(self, resource_name: str, _mode: str="inputs", **kwargs):
         """
@@ -749,6 +759,7 @@ class DSLibrary(object):
             sql - SQL to execute
             sql_table - name of table to fully load
             nosql_collection - name of a NoSQL collection to fully load
+            run_data - True to read using open_run_data()
 
         :param resource_name:   The name of an input resource, or of a local file, or the URI of an external resource.
         """
@@ -789,6 +800,10 @@ class DSLibrary(object):
         format_options = open_args.pop("format_options", None) or {}
         # various formats and their read function
         if format in PANDAS_READ_FORMATS:
+            if open_args.get("run_data"):
+                # read from run data
+                with self.open_run_data(resource_name, mode='rb') as f_r:
+                    return PANDAS_READ_FORMATS[format](f_r, **format_options)
             with self.open_resource(resource_name, mode='rb', **kwargs) as f_r:
                 return PANDAS_READ_FORMATS[format](f_r, **format_options)
         # TODO support read from folder, i.e. folder of CSVs, parquet, etc.
