@@ -40,6 +40,15 @@ class DSLibraryViaMMLibrary(DSLibrary):
         if mandatory:
             raise DSLibraryException(f"method not found: {args[0]}()")
 
+    def _setup_code_paths(self):
+        """
+        If mmlibrary defines a method to setup code paths we call it first.
+        """
+        setup_code_paths = self._find_method("setup_code_paths", mandatory=False)
+        if setup_code_paths:
+            setup_code_paths()
+        super(DSLibraryViaMMLibrary, self)._setup_code_paths()
+
     def get_parameters(self):
         if not self._mm:
             return {}
@@ -106,6 +115,7 @@ class DSLibraryViaMMLibrary(DSLibrary):
                 raise ValueError(f"Unsupported mode for model binary with parts: {mode}")
             with self.open_model_binary() as f_r:
                 with zipfile.ZipFile(f_r) as zf:
+                    # TODO this won't work with large data -- write to a temporary file and read from there, delete file on close
                     if mode == "r":
                         return io.StringIO(zf.read(part).decode("utf-8"))
                     if mode == "rb":
